==> rechn_mgm_web-0.1.7.gem: app/controllers/rechn_mgm_web/api/v1/api_documents_controller.rb <==
require_dependency "rechn_mgm_web/application_controller"

module RechnMgmWeb
    class Api::V1::ApiDocumentsController < AuthenticatedController
        protect_from_forgery except: [:set_validation_state, :assign_to_user, :back_to_origin, :add_comment], prepend: true #, with: :exception, unless: -> { request.format.json? }

        before_action :set_document, only: [:set_validation_state, :assign_to_user, :back_to_origin, :add_comment, :export, :preview]

        def show
            @document = Nukleus::Document.find(api_document_params[:id])
        end

        # Return documents assigned to current_user.
        def index
            @documents = Nukleus::Document.all_by_user(current_user)
        end

        def index_as_ids
            render json: Nukleus::Document.all_ids_by_user(current_user), status: :ok
        end

        # Return all documents with a given validation state..
        def index_all
            @documents = Nukleus::Document.all_by_validation(api_document_params[:validation].to_i, current_user)

            render :index
        end

        def index_validated
            @documents = Nukleus::Document.all_validated(current_user)

            render :index
        end

        # Return all documents not assigned with a given validation state
        def index_unassigned
            if api_document_params[:validation].present?
                @documents = Nukleus::Document.unassigned_by_validation(api_document_params[:validation].to_i, current_user)
            else
                @documents = Nukleus::Document.unassigned(current_user)
            end
            render :index
        end

        def index_assigned
            if api_document_params[:validation].present?
                @documents = Nukleus::Document.assigned_by_validation(api_document_params[:validation].to_i, current_user)
            else
                @documents = Nukleus::Document.assigned(current_user)
            end

            render :index
        end

        def status_overview
            render json: Nukleus::Document.status_overview(current_user), status: :ok
        end

        def status_user
            render json: Nukleus::Document.status_user(api_document_params[:user_ids].split(","), current_user), status: :ok
        end

        def set_validation_state
            @message = "Success"
            @error   = 0
            if !@document.set_validation_state(current_user, api_document_params[:state].to_i, api_document_params[:comment])
                @message = @document.errors[:messages]
                @error   = 1
            end
        end

        def assign_to_user
            @message = "Success"
            @error   = 0

            dest_user = DeviseAuthentication::User.where(id: api_document_params[:user_id]).first
            if dest_user.nil?
                @message = "User with id #{api_document_params[:user_id]} could not be found"
                @error   = 1
            end

            if @error == 0 && !@document.assign_to_user(current_user, dest_user, api_document_params[:comment])
                @message = @document.errors[:messages]
                @error   = 2
            end
        end

        def back_to_origin
            @message = "Success"
            @error   = 0

            if !@document.back_to_origin(current_user, api_document_params[:comment])
                @message = @document.errors[:messages]
                @error   = 1
            end
        end

        def add_comment
            @message = "Success"
            @error   = 0

            if !@document.add_comment(current_user, api_document_params[:comment])
                @message = @document.errors[:messages]
                @error   = 1
            end
        end

        def export
            @message = "Success"
            @error   = 0

            if !@document.export(current_user)
                @message = "unable to export document"
                @error   = 1
            end
        end

        def preview
            image = @document.preview(api_document_params[:width].to_i, api_document_params[:height].to_i)

            if api_document_params[:base64] == 'true'
                render json: { image: Base64.strict_encode64(image)}, status: :ok
            else
                send_data image, :type => "application/jpeg"
            end
        end

        private
        def set_document
            @document = Nukleus::Document.find(api_document_params[:id])
        end

        def api_document_params
            params.permit(:id, :validation, :user_id, :state, :comment, :width, :height, :user_ids, :base64)
        end
    end
end

==> rechn_mgm_web-0.1.16.gem: app/controllers/rechn_mgm_web/api/v1/api_documents_controller.rb <==
require_dependency "rechn_mgm_web/application_controller"

module RechnMgmWeb
    class Api::V1::ApiDocumentsController < AuthenticatedController
        protect_from_forgery except: [:set_validation_state, :assign_to_user, :back_to_origin, :add_comment], prepend: true #, with: :exception, unless: -> { request.format.json? }

        before_action :set_document, only: [:set_validation_state, :assign_to_user, :back_to_origin, :add_comment, :export, :preview]

        def show
            @document = Nukleus::Document.find(api_document_params[:id])
        end

        # Return documents assigned to current_user.
        def index
            @documents = Nukleus::Document.all_by_user(current_user)
        end

        def index_as_ids
            render json: Nukleus::Document.all_ids_by_user(current_user), status: :ok
        end

        # Return all documents with a given validation state..
        def index_all
            @documents = Nukleus::Document.all_by_validation(api_document_params[:validation].to_i, current_user)

            render :index
        end

        def index_validated
            @documents = Nukleus::Document.all_validated(current_user)

            render :index
        end

        # Return all documents not assigned with a given validation state
        def index_unassigned
            if api_document_params[:validation].present?
                @documents = Nukleus::Document.unassigned_by_validation(api_document_params[:validation].to_i, current_user)
            else
                @documents = Nukleus::Document.unassigned(current_user)
            end
            render :index
        end

        def index_assigned
            if api_document_params[:validation].present?
                @documents = Nukleus::Document.assigned_by_validation(api_document_params[:validation].to_i, current_user)
            else
                @documents = Nukleus::Document.assigned(current_user)
            end

            render :index
        end

        def status_overview
            render json: Nukleus::Document.status_overview(current_user), status: :ok
        end

        def status_user
            render json: Nukleus::Document.status_user(api_document_params[:user_ids].split(","), current_user), status: :ok
        end

        def set_validation_state
            @message = "Success"
            @error   = 0
            if !@document.set_validation_state(current_user, api_document_params[:state].to_i, api_document_params[:comment])
                @message = @document.errors[:messages]
                @error   = 1
            end
        end

        def assign_to_user
            @message = "Success"
            @error   = 0

            dest_user = DeviseAuthentication::User.where(id: api_assign_document_params[:user_id]).first

            # Find membership of destination user for organisation of current user.
            current_organisation = current_user.current_organisation
            membership_of_dest_user = RechnMgmUserArea::MemberShip.where(user_id: dest_user.id, organisation_id: current_organisation.id).first

            fails "Assign to user not possible if no membership relation exists" if membership_of_dest_user.nil?
            dest_user.current_membership_id = membership_of_dest_user.id

            if dest_user.nil?
                @message = "User with id #{api_document_params[:user_id]} could not be found"
                @error   = 1
            end

            if @error == 0 && !@document.assign_to_user(current_user, dest_user, api_document_params[:comment])
                @message = @document.errors[:messages]
                @error   = 2
            end
        end

        def back_to_origin
            @message = "Success"
            @error   = 0

            if !@document.back_to_origin(current_user, api_document_params[:comment])
                @message = @document.errors[:messages]
                @error   = 1
            end
        end

        def add_comment
            @message = "Success"
            @error   = 0

            if !@document.add_comment(current_user, api_document_params[:comment])
                @message = @document.errors[:messages]
                @error   = 1
            end
        end

        def export
            @message = "Success"
            @error   = 0

            if !@document.export(current_user)
                @message = "unable to export document"
                @error   = 1
            end
        end

        def preview
            image = @document.preview(api_document_params[:width].to_i, api_document_params[:height].to_i)

            if api_document_params[:base64] == 'true'
                render json: { image: Base64.strict_encode64(image)}, status: :ok
            else
                send_data image, :type => "application/jpeg"
            end
        end

        private
        def set_document
            @document = Nukleus::Document.find(api_document_params[:id])
        end

        def api_document_params
            params.permit(:id, :validation, :user_id, :state, :comment, :width, :height, :user_ids, :base64)
        end

        def api_assign_document_params
            params.permit(:id, :user_id, :comment )
        end
    end
end
